==> huaweicloudsdkvss-3.0.80-py2.py3-none-any.whl: huaweicloudsdkvss/v3/model/show_results_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResultsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[VulnItem]',
        'statistics': 'VulnsLevel'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data',
        'statistics': 'statistics'
    }

    def __init__(self, total=None, data=None, statistics=None):
        """ShowResultsResponse - a model defined in huaweicloud sdk"""
        
        super(ShowResultsResponse, self).__init__()

        self._total = None
        self._data = None
        self._statistics = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if data is not None:
            self.data = data
        if statistics is not None:
            self.statistics = statistics

    @property
    def total(self):
        """Gets the total of this ShowResultsResponse.

        漏洞总数

        :return: The total of this ShowResultsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ShowResultsResponse.

        漏洞总数

        :param total: The total of this ShowResultsResponse.
        :type: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this ShowResultsResponse.

        漏洞信息列表

        :return: The data of this ShowResultsResponse.
        :rtype: list[VulnItem]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ShowResultsResponse.

        漏洞信息列表

        :param data: The data of this ShowResultsResponse.
        :type: list[VulnItem]
        """
        self._data = data

    @property
    def statistics(self):
        """Gets the statistics of this ShowResultsResponse.


        :return: The statistics of this ShowResultsResponse.
        :rtype: VulnsLevel
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """Sets the statistics of this ShowResultsResponse.


        :param statistics: The statistics of this ShowResultsResponse.
        :type: VulnsLevel
        """
        self._statistics = statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResultsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvss-3.0.105-py2.py3-none-any.whl: huaweicloudsdkvss/v3/model/show_results_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResultsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[VulnItem]',
        'statistics': 'VulnsLevel'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data',
        'statistics': 'statistics'
    }

    def __init__(self, total=None, data=None, statistics=None):
        """ShowResultsResponse

        The model defined in huaweicloud sdk

        :param total: 漏洞总数
        :type total: int
        :param data: 漏洞信息列表
        :type data: list[:class:`huaweicloudsdkvss.v3.VulnItem`]
        :param statistics: 
        :type statistics: :class:`huaweicloudsdkvss.v3.VulnsLevel`
        """
        
        super(ShowResultsResponse, self).__init__()

        self._total = None
        self._data = None
        self._statistics = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if data is not None:
            self.data = data
        if statistics is not None:
            self.statistics = statistics

    @property
    def total(self):
        """Gets the total of this ShowResultsResponse.

        漏洞总数

        :return: The total of this ShowResultsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ShowResultsResponse.

        漏洞总数

        :param total: The total of this ShowResultsResponse.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this ShowResultsResponse.

        漏洞信息列表

        :return: The data of this ShowResultsResponse.
        :rtype: list[:class:`huaweicloudsdkvss.v3.VulnItem`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ShowResultsResponse.

        漏洞信息列表

        :param data: The data of this ShowResultsResponse.
        :type data: list[:class:`huaweicloudsdkvss.v3.VulnItem`]
        """
        self._data = data

    @property
    def statistics(self):
        """Gets the statistics of this ShowResultsResponse.


        :return: The statistics of this ShowResultsResponse.
        :rtype: :class:`huaweicloudsdkvss.v3.VulnsLevel`
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """Sets the statistics of this ShowResultsResponse.


        :param statistics: The statistics of this ShowResultsResponse.
        :type statistics: :class:`huaweicloudsdkvss.v3.VulnsLevel`
        """
        self._statistics = statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResultsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
